#
# Syntax Usage:
#   c:\python33\python.exe $(ThisScriptName).py <filepath> [-r | -recursive]
#

import hashlib
import os
import sys


def get_files_from_directory(directory, recursive=False):
	"""@param directory: directory path
	@param recursive: None or True, if True handle directory recursive
	@return: flat list of files inside directory according to recursive flag
	"""
	for dirPath, subDirs, files in os.walk(directory, True):  #os.walk() don't walk to symbolic links to subdirectories
		for filename in files:
			yield(os.path.join(dirPath, filename))
		if not recursive:  #if we don't want to handle directory recursive we must stop here
			break

def md5_of_file(filename):
	md5 = hashlib.md5()
	with open(filename, 'rb') as f :
		for chunk in iter(lambda: f.read(md5.block_size * 128), ''):
			if not chunk:
				break
			md5.update(chunk)
	return md5.hexdigest().upper()

def get_human_readable_size(size):
	for x in ['bytes','KB','MB','GB']:
		if size < 1024.0 and size > -1024.0:
			return "%3.1f%s" % (size, x)
		size /= 1024.0
	return "%3.1f%s" % (size, 'TB')

def printFileDescriptor(directory, filename):
	separator = '\n'
	fileSize = os.stat(filename).st_size
	humanSize = get_human_readable_size(fileSize)
	descriptor = os.path.relpath(filename, directory) + separator + \
		'    MD5 : %s' % md5_of_file(filename) + separator + \
		'    Size: %s (%s bytes)' % (humanSize, fileSize) + separator
	print(descriptor, file=sys.stdout)

def printDescriptor(directory, filenames):
	print(os.path.abspath(directory) + os.sep + os.linesep, file=sys.stdout)
	for filename in filenames:
		printFileDescriptor(directory, filename)

def do_main():
	if len(sys.argv) < 2 or len(sys.argv) > 3 :
		print('Invalid command line', file=sys.stderr)
		sys.exit(-1)

	directory = sys.argv[1]
	if not (os.path.isdir(directory) and os.path.exists(directory) ):
		print('Invalid directory path', file=sys.stderr)
		sys.exit(-1)

	recursive = (len(sys.argv) == 3) and sys.argv[2].startswith('-r')

	filenames = get_files_from_directory(directory, recursive)

	printDescriptor(directory, filenames)

if __name__ == '__main__' :
	do_main()
