
#
# Syntax usage:
#   $(Python_3.x)\python.exe .\\md5checksum.py <directory path> [-r | --recursive]
#

import os
import sys
import hashlib

def get_files_from_directory(directory, recursive=False):
	"""@param directory: directory path
	@param recursive: None or True, if True handle directory recursive
	@return: flat list of files inside directory according to recursive flag
	"""
	result = []
	for dirPath, subDirs, files in os.walk(directory, True):  #os.walk() don't walk to symbolic links to subdirectories
		files = map(lambda x: os.path.join(dirPath, x), files)
		result.extend(files)
		if not recursive:  #if we don't want to handle directory recursive we must stop here
			break
	return result

def md5_of_file(filename):
	md5 = hashlib.md5()
	with open(filename, 'rb') as f :
		for chunk in iter(lambda: f.read(md5.block_size * 128), ''):
			if not chunk:
				break
			md5.update(chunk)
	return md5.hexdigest().upper()

if __name__ == '__main__' :
	directory = sys.argv[1]
	recursive = False
	try:
		option = sys.argv[2].upper()
		recursive = (option == '--RECURSIVE') or (option == '-R')
	except IndexError:
		pass
	except BaseException as e:
		print(e, file=sys.stderr)

	filenames = get_files_from_directory(directory, recursive)
	for filename in filenames :
		if not os.path.isfile(filename):
			print('Skipped "%s". This is not file' % filename, file=sys.stderr)
			continue
		relname = os.path.relpath(filename, directory)
		md5 = md5_of_file(filename)
		line = 'MD5 ( %s ) = %s' % (relname, md5)
		print(line, file=sys.stdout)
