
# Syntax usage:
#   c:\\python33\\python.exe sort-json.py <filename>

import json
import sys


class SortJsonException(Exception):
	def __init__(self, err_text):
		Exception.__init__(self)
		self._err_text = err_text

	def __str__(self):
		return self._err_text


def read_from_file(filename):
	try:
		result = None
		with open(filename, 'rb') as f:
			result = f.read().decode('ascii')
		return result
	except FileNotFoundError as e:
		raise SortJsonException('Read file error: %s' % e)

def parse_json(content):
	try:
		return json.loads(content)
	except ValueError as e:
		raise SortJsonException('Parse error: %s' % e)

def sort_json(content):
	return json.dumps(content, indent='\t', sort_keys=True)

if __name__ == '__main__' :
	try:
		filename = sys.argv[1]
		content = read_from_file(filename)
		parsed = parse_json(content)
		sorted = sort_json(parsed)
		print(sorted)
		sys.exit(0)
	except SortJsonException as e:
		print('%s' % e, file=sys.stderr)
		sys.exit(-1)
	except IndexError:
		print('Usage:\n  python sort_json.py <filename>', file=sys.stderr)
		sys.exit(-1)
